nxp-pac

Crates

git

Versions

mimxrt1011

Flavors

Hp0

Struct Hp0 

#[repr(transparent)]
pub struct Hp0(pub u32);
HP0 register

Tuple Fields

0: u32

Implementations

Source

impl Hp0

pub const fn hp_dma(&self) -> HpDma

Determines whether the register value of the corresponding HP field is passed as the hprot[1] of the eDMA

pub const fn set_hp_dma(&mut self, val: HpDma)

Determines whether the register value of the corresponding HP field is passed as the hprot[1] of the eDMA

pub const fn l_dma(&self) -> Hp0LDma

Lock bit set by the TZ software for the eDMA

pub const fn set_l_dma(&mut self, val: Hp0LDma)

Lock bit set by the TZ software for the eDMA

pub const fn hp_lcdif(&self) -> HpLcdif

Determines whether the register value of the corresponding HP field is passed as the hprot[1] of the LCDIF

pub const fn set_hp_lcdif(&mut self, val: HpLcdif)

Determines whether the register value of the corresponding HP field is passed as the hprot[1] of the LCDIF

pub const fn l_lcdif(&self) -> Hp0LLcdif

Lock bit set by the TZ software for the LCDIF

pub const fn set_l_lcdif(&mut self, val: Hp0LLcdif)

Lock bit set by the TZ software for the LCDIF

pub const fn hp_csi(&self) -> HpCsi

Determines whether the register value of the corresponding HP field is passed as the hprot[1] of the CSI

pub const fn set_hp_csi(&mut self, val: HpCsi)

Determines whether the register value of the corresponding HP field is passed as the hprot[1] of the CSI

pub const fn l_csi(&self) -> Hp0LCsi

Lock bit set by the TZ software for the CSI

pub const fn set_l_csi(&mut self, val: Hp0LCsi)

Lock bit set by the TZ software for the CSI

pub const fn hp_pxp(&self) -> HpPxp

Determines whether the register value of the corresponding HP field is passed as the hprot[1] of the PXP

pub const fn set_hp_pxp(&mut self, val: HpPxp)

Determines whether the register value of the corresponding HP field is passed as the hprot[1] of the PXP

pub const fn l_pxp(&self) -> Hp0LPxp

Lock bit set by the TZ software for the PXP

pub const fn set_l_pxp(&mut self, val: Hp0LPxp)

Lock bit set by the TZ software for the PXP

pub const fn hp_dcp(&self) -> HpDcp

Determines whether the register value of the corresponding HP field is passed as the hprot[1] of the DCP

pub const fn set_hp_dcp(&mut self, val: HpDcp)

Determines whether the register value of the corresponding HP field is passed as the hprot[1] of the DCP

pub const fn l_dcp(&self) -> Hp0LDcp

Lock bit set by the TZ software for the DCP

pub const fn set_l_dcp(&mut self, val: Hp0LDcp)

Lock bit set by the TZ software for the DCP

pub const fn hp_enet(&self) -> HpEnet

Determines whether the register value of the corresponding HP field is passed as the hprot[1] of the ENET

pub const fn set_hp_enet(&mut self, val: HpEnet)

Determines whether the register value of the corresponding HP field is passed as the hprot[1] of the ENET

pub const fn l_enet(&self) -> Hp0LEnet

Lock bit set by the TZ software for the ENET

pub const fn set_l_enet(&mut self, val: Hp0LEnet)

Lock bit set by the TZ software for the ENET

pub const fn hp_usdhc1(&self) -> HpUsdhc1

Determines whether the register value of the corresponding HP field is passed as the hprot[1] of the USDHC1

pub const fn set_hp_usdhc1(&mut self, val: HpUsdhc1)

Determines whether the register value of the corresponding HP field is passed as the hprot[1] of the USDHC1

pub const fn l_usdhc1(&self) -> Hp0LUsdhc1

Lock bit set by the TZ software for the USDHC1

pub const fn set_l_usdhc1(&mut self, val: Hp0LUsdhc1)

Lock bit set by the TZ software for the USDHC1

pub const fn hp_usdhc2(&self) -> HpUsdhc2

Determines whether the register value of the corresponding HP field is passed as the hprot[1] of the USDHC2

pub const fn set_hp_usdhc2(&mut self, val: HpUsdhc2)

Determines whether the register value of the corresponding HP field is passed as the hprot[1] of the USDHC2

pub const fn l_usdhc2(&self) -> Hp0LUsdhc2

Lock bit set by the TZ software for the USDHC2

pub const fn set_l_usdhc2(&mut self, val: Hp0LUsdhc2)

Lock bit set by the TZ software for the USDHC2

pub const fn hp_tpsmp(&self) -> HpTpsmp

Determines whether the register value of the corresponding HP field is passed as the hprot[1] of the TPSMP

pub const fn set_hp_tpsmp(&mut self, val: HpTpsmp)

Determines whether the register value of the corresponding HP field is passed as the hprot[1] of the TPSMP

pub const fn l_tpsmp(&self) -> Hp0LTpsmp

Lock bit set by the TZ software for the TPSMP

pub const fn set_l_tpsmp(&mut self, val: Hp0LTpsmp)

Lock bit set by the TZ software for the TPSMP

pub const fn hp_usb(&self) -> HpUsb

Determines whether the register value of the corresponding HP field is passed as the hprot[1] of the USB

pub const fn set_hp_usb(&mut self, val: HpUsb)

Determines whether the register value of the corresponding HP field is passed as the hprot[1] of the USB

pub const fn l_usb(&self) -> Hp0LUsb

Lock bit set by the TZ software for the USB

pub const fn set_l_usb(&mut self, val: Hp0LUsb)

Lock bit set by the TZ software for the USB