#[repr(transparent)]pub struct Hp0(pub u32);Expand description
HP0 register
Tuple Fields
0: u32Implementations
Sourceimpl Hp0
impl Hp0
Sourcepub const fn hp_dma(&self) -> HpDma
pub const fn hp_dma(&self) -> HpDma
Determines whether the register value of the corresponding HP field is passed as the hprot[1] of the eDMA
Sourcepub const fn set_hp_dma(&mut self, val: HpDma)
pub const fn set_hp_dma(&mut self, val: HpDma)
Determines whether the register value of the corresponding HP field is passed as the hprot[1] of the eDMA
Sourcepub const fn hp_lcdif(&self) -> HpLcdif
pub const fn hp_lcdif(&self) -> HpLcdif
Determines whether the register value of the corresponding HP field is passed as the hprot[1] of the LCDIF
Sourcepub const fn set_hp_lcdif(&mut self, val: HpLcdif)
pub const fn set_hp_lcdif(&mut self, val: HpLcdif)
Determines whether the register value of the corresponding HP field is passed as the hprot[1] of the LCDIF
Sourcepub const fn set_l_lcdif(&mut self, val: Hp0LLcdif)
pub const fn set_l_lcdif(&mut self, val: Hp0LLcdif)
Lock bit set by the TZ software for the LCDIF
Sourcepub const fn hp_csi(&self) -> HpCsi
pub const fn hp_csi(&self) -> HpCsi
Determines whether the register value of the corresponding HP field is passed as the hprot[1] of the CSI
Sourcepub const fn set_hp_csi(&mut self, val: HpCsi)
pub const fn set_hp_csi(&mut self, val: HpCsi)
Determines whether the register value of the corresponding HP field is passed as the hprot[1] of the CSI
Sourcepub const fn hp_pxp(&self) -> HpPxp
pub const fn hp_pxp(&self) -> HpPxp
Determines whether the register value of the corresponding HP field is passed as the hprot[1] of the PXP
Sourcepub const fn set_hp_pxp(&mut self, val: HpPxp)
pub const fn set_hp_pxp(&mut self, val: HpPxp)
Determines whether the register value of the corresponding HP field is passed as the hprot[1] of the PXP
Sourcepub const fn hp_dcp(&self) -> HpDcp
pub const fn hp_dcp(&self) -> HpDcp
Determines whether the register value of the corresponding HP field is passed as the hprot[1] of the DCP
Sourcepub const fn set_hp_dcp(&mut self, val: HpDcp)
pub const fn set_hp_dcp(&mut self, val: HpDcp)
Determines whether the register value of the corresponding HP field is passed as the hprot[1] of the DCP
Sourcepub const fn hp_enet(&self) -> HpEnet
pub const fn hp_enet(&self) -> HpEnet
Determines whether the register value of the corresponding HP field is passed as the hprot[1] of the ENET
Sourcepub const fn set_hp_enet(&mut self, val: HpEnet)
pub const fn set_hp_enet(&mut self, val: HpEnet)
Determines whether the register value of the corresponding HP field is passed as the hprot[1] of the ENET
Sourcepub const fn set_l_enet(&mut self, val: Hp0LEnet)
pub const fn set_l_enet(&mut self, val: Hp0LEnet)
Lock bit set by the TZ software for the ENET
Sourcepub const fn hp_usdhc1(&self) -> HpUsdhc1
pub const fn hp_usdhc1(&self) -> HpUsdhc1
Determines whether the register value of the corresponding HP field is passed as the hprot[1] of the USDHC1
Sourcepub const fn set_hp_usdhc1(&mut self, val: HpUsdhc1)
pub const fn set_hp_usdhc1(&mut self, val: HpUsdhc1)
Determines whether the register value of the corresponding HP field is passed as the hprot[1] of the USDHC1
Sourcepub const fn l_usdhc1(&self) -> Hp0LUsdhc1
pub const fn l_usdhc1(&self) -> Hp0LUsdhc1
Lock bit set by the TZ software for the USDHC1
Sourcepub const fn set_l_usdhc1(&mut self, val: Hp0LUsdhc1)
pub const fn set_l_usdhc1(&mut self, val: Hp0LUsdhc1)
Lock bit set by the TZ software for the USDHC1
Sourcepub const fn hp_usdhc2(&self) -> HpUsdhc2
pub const fn hp_usdhc2(&self) -> HpUsdhc2
Determines whether the register value of the corresponding HP field is passed as the hprot[1] of the USDHC2
Sourcepub const fn set_hp_usdhc2(&mut self, val: HpUsdhc2)
pub const fn set_hp_usdhc2(&mut self, val: HpUsdhc2)
Determines whether the register value of the corresponding HP field is passed as the hprot[1] of the USDHC2
Sourcepub const fn l_usdhc2(&self) -> Hp0LUsdhc2
pub const fn l_usdhc2(&self) -> Hp0LUsdhc2
Lock bit set by the TZ software for the USDHC2
Sourcepub const fn set_l_usdhc2(&mut self, val: Hp0LUsdhc2)
pub const fn set_l_usdhc2(&mut self, val: Hp0LUsdhc2)
Lock bit set by the TZ software for the USDHC2
Sourcepub const fn hp_tpsmp(&self) -> HpTpsmp
pub const fn hp_tpsmp(&self) -> HpTpsmp
Determines whether the register value of the corresponding HP field is passed as the hprot[1] of the TPSMP
Sourcepub const fn set_hp_tpsmp(&mut self, val: HpTpsmp)
pub const fn set_hp_tpsmp(&mut self, val: HpTpsmp)
Determines whether the register value of the corresponding HP field is passed as the hprot[1] of the TPSMP
Sourcepub const fn set_l_tpsmp(&mut self, val: Hp0LTpsmp)
pub const fn set_l_tpsmp(&mut self, val: Hp0LTpsmp)
Lock bit set by the TZ software for the TPSMP
Sourcepub const fn hp_usb(&self) -> HpUsb
pub const fn hp_usb(&self) -> HpUsb
Determines whether the register value of the corresponding HP field is passed as the hprot[1] of the USB
Sourcepub const fn set_hp_usb(&mut self, val: HpUsb)
pub const fn set_hp_usb(&mut self, val: HpUsb)
Determines whether the register value of the corresponding HP field is passed as the hprot[1] of the USB